nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

SystCalib

Struct SystCalib 

#[repr(transparent)]
pub struct SystCalib(pub u32);
SysTick Calibration Value Register

Tuple Fields

0: u32

Implementations

Source

impl SystCalib

pub const fn tenms(&self) -> u32

Reload value to use for 10ms timing

pub const fn set_tenms(&mut self, val: u32)

Reload value to use for 10ms timing

pub const fn skew(&self) -> Skew

Indicates whether the TENMS value is exact

pub const fn set_skew(&mut self, val: Skew)

Indicates whether the TENMS value is exact

pub const fn noref(&self) -> Noref

Indicates whether the device provides an alternative reference clock

pub const fn set_noref(&mut self, val: Noref)

Indicates whether the device provides an alternative reference clock