nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

SystRvr

Struct SystRvr 

#[repr(transparent)]
pub struct SystRvr(pub u32);
SysTick Reload Value Register

Tuple Fields

0: u32

Implementations

Source

impl SystRvr

pub const fn reload(&self) -> u32

Value to load into the SysTick Current Value Register when the counter reaches 0

pub const fn set_reload(&mut self, val: u32)

Value to load into the SysTick Current Value Register when the counter reaches 0